@@ -16,9 +16,7 @@ class ModelSet:
         self.config = config
         self.base_folder = base_folder
 
-        logger.debug(
-            f"base folder: {self.base_folder}\n" f"configs: {self.config}"
-        )
+        logger.debug(f"base folder: {self.base_folder}\n" f"configs: {self.config}")
 
     def create_model(self):
         """
